@@ -22,7 +22,7 @@
 #include "job.h"
 #include "job_p.h"
 #include "akonadicore_debug.h"
-#include "KDBusConnectionPool"
+#include <QDBusConnection>
 #include <QTime>
 #include "private/protocol_p.h"
 #include "private/instance_p.h"
@@ -32,6 +32,7 @@
 #include <KLocalizedString>
 
 #include <QTimer>
+#include <QElapsedTimer>
 #include <QDBusInterface>
 #include <QDBusConnectionInterface>
 
@@ -114,17 +115,17 @@ void JobPrivate::publishJob()
     if (!s_jobtracker) {
         // Let's only check for the debugging console every 3 seconds, otherwise every single job
         // makes a dbus call to the dbus daemon, doesn't help performance.
-        static QTime s_lastTime;
-        if (s_lastTime.isNull() || s_lastTime.elapsed() > 3000) {
-            if (s_lastTime.isNull()) {
+        static QElapsedTimer s_lastTime;
+        if (!s_lastTime.isValid() || s_lastTime.elapsed() > 3000) {
+            if (!s_lastTime.isValid()) {
                 s_lastTime.start();
             }
             const QString suffix  = Akonadi::Instance::identifier().isEmpty() ? QString() : QLatin1Char('-') + Akonadi::Instance::identifier();
-            if (KDBusConnectionPool::threadConnection().interface()->isServiceRegistered(QStringLiteral("org.kde.akonadiconsole") + suffix)) {
+            if (QDBusConnection::sessionBus().interface()->isServiceRegistered(QStringLiteral("org.kde.akonadiconsole") + suffix)) {
                 s_jobtracker = new QDBusInterface(QLatin1String("org.kde.akonadiconsole") + suffix,
                                                   QStringLiteral("/jobtracker"),
                                                   QStringLiteral("org.freedesktop.Akonadi.JobTracker"),
-                                                  KDBusConnectionPool::threadConnection(), nullptr);
+                                                  QDBusConnection::sessionBus(), nullptr);
                 mSession->d->publishOtherJobs(q);
             } else {
                 s_lastTime.restart();
