@@ -22,10 +22,10 @@
 #ifndef AKONADI_ENTITYORDERPROXYMODEL_H
 #define AKONADI_ENTITYORDERPROXYMODEL_H
 
-#include <KRecursiveFilterProxyModel>
+#include "akonadicore_export.h"
 #include "collection.h"
 
-#include "akonadicore_export.h"
+#include <QSortFilterProxyModel>
 
 class KConfigGroup;
 
@@ -42,7 +42,7 @@ class EntityOrderProxyModelPrivate;
  * @author Stephen Kelly <stephen@kdab.com>
  * @since 4.6
  */
-class AKONADICORE_EXPORT EntityOrderProxyModel : public KRecursiveFilterProxyModel
+class AKONADICORE_EXPORT EntityOrderProxyModel : public QSortFilterProxyModel
 {
     Q_OBJECT
 
@@ -75,17 +75,17 @@ public:
     /**
      * @reimp
      */
-    bool lessThan(const QModelIndex &left, const QModelIndex &right) const override;
+    Q_REQUIRED_RESULT bool lessThan(const QModelIndex &left, const QModelIndex &right) const override;
 
     /**
      * @reimp
      */
-    bool dropMimeData(const QMimeData *data, Qt::DropAction action, int row, int column, const QModelIndex &parent) override;
+    Q_REQUIRED_RESULT bool dropMimeData(const QMimeData *data, Qt::DropAction action, int row, int column, const QModelIndex &parent) override;
 
     /**
      * @reimp
      */
-    QModelIndexList match(const QModelIndex &start, int role, const QVariant &value, int hits = 1,
+    Q_REQUIRED_RESULT QModelIndexList match(const QModelIndex &start, int role, const QVariant &value, int hits = 1,
                           Qt::MatchFlags flags = Qt::MatchFlags(Qt::MatchStartsWith | Qt::MatchWrap)) const override;
 
 protected:
