@@ -23,7 +23,13 @@
 #include <QObject>
 #include <QVector>
 
+#include <memory>
+
+#include <shared/akoptional.h>
+
 class QProcess;
+class QDBusServiceWatcher;
+class QSettings;
 
 namespace Akonadi
 {
@@ -39,14 +45,19 @@ class CacheCleaner;
 class IntervalCheck;
 class AkLocalServer;
 class NotificationManager;
+class ResourceManager;
+class CollectionStatistics;
+class PreprocessorManager;
+class Tracer;
+class DebugInterface;
 
 class AkonadiServer : public QObject
 {
     Q_OBJECT
 
 public:
+    explicit AkonadiServer();
     ~AkonadiServer();
-    static AkonadiServer *instance();
 
     /**
      * Can return a nullptr
@@ -56,7 +67,21 @@ public:
     /**
      * Returns the IntervalCheck instance. Never nullptr.
      */
-    IntervalCheck *intervalChecker();
+    IntervalCheck &intervalChecker();
+
+    ResourceManager &resourceManager();
+
+    CollectionStatistics &collectionStatistics();
+
+    PreprocessorManager &preprocessorManager();
+
+    SearchTaskManager &agentSearchManager();
+
+    SearchManager &searchManager();
+
+    ItemRetrievalManager &itemRetrievalManager();
+
+    Tracer &tracer();
 
     /**
      * Instance-aware server .config directory
@@ -81,33 +106,37 @@ protected Q_SLOTS:
 
 private Q_SLOTS:
     void doQuit();
-    void serviceOwnerChanged(const QString &name, const QString &oldOwner, const QString &newOwner);
     void connectionDisconnected();
 
 private:
     bool startDatabaseProcess();
     bool createDatabase();
     void stopDatabaseProcess();
+    bool createServers(QSettings &settings, QSettings &connectionSettings);
+    bool setupDatabase();
     uint userId() const;
 
 protected:
-    AkonadiServer(QObject *parent = nullptr);
+    std::unique_ptr<QDBusServiceWatcher> mControlWatcher;
 
-    AkLocalServer *mCmdServer = nullptr;
-    AkLocalServer *mNtfServer = nullptr;
+    std::unique_ptr<AkLocalServer> mCmdServer;
+    std::unique_ptr<AkLocalServer> mNtfServer;
 
-    NotificationManager *mNotificationManager = nullptr;
-    CacheCleaner *mCacheCleaner = nullptr;
-    IntervalCheck *mIntervalCheck = nullptr;
-    StorageJanitor *mStorageJanitor = nullptr;
-    ItemRetrievalManager *mItemRetrieval = nullptr;
-    SearchTaskManager *mAgentSearchManager = nullptr;
-    QProcess *mDatabaseProcess = nullptr;
-    QVector<Connection *> mConnections;
-    SearchManager *mSearchManager = nullptr;
+    std::unique_ptr<ResourceManager> mResourceManager;
+    std::unique_ptr<DebugInterface> mDebugInterface;
+    std::unique_ptr<CollectionStatistics> mCollectionStats;
+    std::unique_ptr<PreprocessorManager> mPreprocessorManager;
+    std::unique_ptr<NotificationManager> mNotificationManager;
+    std::unique_ptr<CacheCleaner> mCacheCleaner;
+    std::unique_ptr<IntervalCheck> mIntervalCheck;
+    std::unique_ptr<StorageJanitor> mStorageJanitor;
+    std::unique_ptr<ItemRetrievalManager> mItemRetrieval;
+    std::unique_ptr<SearchTaskManager> mAgentSearchManager;
+    std::unique_ptr<SearchManager> mSearchManager;
+    std::unique_ptr<Tracer> mTracer;
+
+    std::vector<std::unique_ptr<Connection>> mConnections;
     bool mAlreadyShutdown = false;
-
-    static AkonadiServer *s_instance;
 };
 
 } // namespace Server
