@@ -28,8 +28,9 @@ using namespace Akonadi::Server;
 static const int MINIMUM_AUTOSYNC_INTERVAL = 5; // minutes
 static const int MINIMUM_COLTREESYNC_INTERVAL = 5; // minutes
 
-IntervalCheck::IntervalCheck(QObject *parent)
-    : CollectionScheduler(QStringLiteral("IntervalCheck"), QThread::IdlePriority, parent)
+IntervalCheck::IntervalCheck(ItemRetrievalManager &itemRetrievalManager)
+    : CollectionScheduler(QStringLiteral("IntervalCheck"), QThread::IdlePriority)
+    , mItemRetrievalManager(itemRetrievalManager)
 {
 }
 
@@ -73,9 +74,7 @@ void IntervalCheck::collectionExpired(const Collection &collection)
         const QDateTime lastExpectedCheck = now.addSecs(interval * -60);
         if (!mLastCollectionTreeSyncs.contains(resourceName) || mLastCollectionTreeSyncs.value(resourceName) < lastExpectedCheck) {
             mLastCollectionTreeSyncs.insert(resourceName, now);
-            QMetaObject::invokeMethod(ItemRetrievalManager::instance(), "triggerCollectionTreeSync",
-                                      Qt::QueuedConnection,
-                                      Q_ARG(QString, resourceName));
+            mItemRetrievalManager.triggerCollectionTreeSync(resourceName);
         }
     }
 
@@ -87,8 +86,5 @@ void IntervalCheck::collectionExpired(const Collection &collection)
         return;
     }
     mLastChecks.insert(collection.id(), now);
-    QMetaObject::invokeMethod(ItemRetrievalManager::instance(), "triggerCollectionSync",
-                              Qt::QueuedConnection,
-                              Q_ARG(QString, collection.resource().name()),
-                              Q_ARG(qint64, collection.id()));
+    mItemRetrievalManager.triggerCollectionSync(collection.resource().name(), collection.id());
 }
