@@ -27,10 +27,10 @@
 using namespace Akonadi;
 using namespace Akonadi::Server;
 
-AgentSearchInstance::AgentSearchInstance(const QString &id)
+AgentSearchInstance::AgentSearchInstance(const QString &id, SearchTaskManager &manager)
     : mId(id)
     , mInterface(nullptr)
-    , mServiceWatcher(nullptr)
+    , mManager(manager)
 {
 }
 
@@ -54,26 +54,17 @@ bool AgentSearchInstance::init()
         return false;
     }
 
-    mServiceWatcher = new QDBusServiceWatcher(DBus::agentServiceName(mId, DBus::Agent),
-            DBusConnectionPool::threadConnection(),
-            QDBusServiceWatcher::WatchForOwnerChange,
-            this);
-    connect(mServiceWatcher, &QDBusServiceWatcher::serviceOwnerChanged,
-            this, &AgentSearchInstance::serviceOwnerChanged);
+    mServiceWatcher = std::make_unique<QDBusServiceWatcher>(
+            DBus::agentServiceName(mId, DBus::Agent), DBusConnectionPool::threadConnection(),
+            QDBusServiceWatcher::WatchForUnregistration);
+    connect(mServiceWatcher.get(), &QDBusServiceWatcher::serviceUnregistered,
+            this, [this]() {
+                mManager.unregisterInstance(mId);
+            });
 
     return true;
 }
 
-void AgentSearchInstance::serviceOwnerChanged(const QString &service, const QString &oldName, const QString &newName)
-{
-    Q_UNUSED(service);
-    Q_UNUSED(oldName);
-
-    if (newName.isEmpty()) {
-        SearchTaskManager::instance()->unregisterInstance(mId);
-    }
-}
-
 void AgentSearchInstance::search(const QByteArray &searchId, const QString &query,
                                  qlonglong collectionId)
 {
