@@ -78,19 +78,20 @@ static QThreadStorage<DataStore *> sInstances;
         } \
     }
 
-DataStore *DataStoreFactory::createStore()
-{
-    return new DataStore();
-}
+std::unique_ptr<DataStoreFactory> DataStore::sFactory;
 
-std::unique_ptr<DataStoreFactory> DataStore::sFactory = std::make_unique<DataStoreFactory>();
+void DataStore::setFactory(std::unique_ptr<DataStoreFactory> factory)
+{
+    sFactory = std::move(factory);
+}
 
 
 /***************************************************************************
  *   DataStore                                                           *
  ***************************************************************************/
-DataStore::DataStore()
+DataStore::DataStore(AkonadiServer &akonadi)
     : QObject()
+    , m_akonadi(akonadi)
     , m_dbOpened(false)
     , m_transactionLevel(0)
     , m_keepAliveTimer(nullptr)
@@ -225,7 +226,7 @@ bool DataStore::init()
 NotificationCollector *DataStore::notificationCollector()
 {
     if (!mNotificationCollector) {
-        mNotificationCollector = std::make_unique<NotificationCollector>(this);
+        mNotificationCollector = std::make_unique<NotificationCollector>(m_akonadi, this);
     }
 
     return mNotificationCollector.get();
@@ -1327,7 +1328,7 @@ void DataStore::debugLastDbError(const char *actionDescription) const
     qCCritical(AKONADISERVER_LOG) << "  Last driver error:" << m_database.lastError().driverText();
     qCCritical(AKONADISERVER_LOG) << "  Last database error:" << m_database.lastError().databaseText();
 
-    Tracer::self()->error("DataStore (Database Error)",
+    m_akonadi.tracer().error("DataStore (Database Error)",
                           QStringLiteral("%1\nDriver said: %2\nDatabase said:%3")
                           .arg(QString::fromLatin1(actionDescription),
                                m_database.lastError().driverText(),
@@ -1341,7 +1342,7 @@ void DataStore::debugLastQueryError(const QSqlQuery &query, const char *actionDe
     qCCritical(AKONADISERVER_LOG) << "  Last driver error:" << m_database.lastError().driverText();
     qCCritical(AKONADISERVER_LOG) << "  Last database error:" << m_database.lastError().databaseText();
 
-    Tracer::self()->error("DataStore (Database Query Error)",
+    m_akonadi.tracer().error("DataStore (Database Query Error)",
                           QStringLiteral("%1: %2")
                           .arg(QString::fromLatin1(actionDescription),
                                query.lastError().text()));
@@ -1514,6 +1515,6 @@ void DataStore::cleanupAfterRollback()
     Resource::invalidateCompleteCache();
     Collection::invalidateCompleteCache();
     PartType::invalidateCompleteCache();
-    CollectionStatistics::self()->expireCache();
+    m_akonadi.collectionStatistics().expireCache();
     QueryCache::clear();
 }
